import axios from "axios";
import { useEffect, useRef } from "react";
import * as cornerstone from "cornerstone-core";
import dicomParser from "dicom-parser";
import cornerstoneDICOMImageLoader from "@cornerstonejs/dicom-image-loader";

interface VolumeViewerProps {
  children?: JSX.Element;
}

const StudyInstanceUID =
  "1.2.840.113619.2.416.200043823236217877797891016883696407563"; // 你的 studyInstanceUID
const SeriesInstanceUID =
  "1.2.840.113619.6.80.114374075765625.22940.1553237925965.1"; // 你的 seriesInstanceUID

export const VolumeViewer = (props: VolumeViewerProps) => {
  const dicomRef = useRef(null);
  const url = `/dicom-web/studies/${StudyInstanceUID}/series/${SeriesInstanceUID}/instances`;

  useEffect(() => {
    cornerstoneDICOMImageLoader.external.cornerstone = cornerstone;
    cornerstoneDICOMImageLoader.external.dicomParser = dicomParser;

    // cornerstoneWADOImageLoader.configure({ useWebWorkers: true });

    const config = {
      maxWebWorkers: navigator.hardwareConcurrency || 1,
      startWebWorkersOnDemand: true,
      taskConfiguration: {
        decodeTask: {
          initializeCodecsOnStartup: false,
        },
      },
    };
    cornerstoneDICOMImageLoader.webWorkerManager.initialize(config);
  }, []);

  useEffect(() => {
    cornerstone.enable(dicomRef.current!);
    axios
      .get(url)
      .then((response) => {
        const objectUIDs = response.data.map(
          (i: any) => i["00080018"].Value[0]
        );
        objectUIDs.forEach((i: any) => {
          const imageId = `wadors:/dicom-web/studies/${StudyInstanceUID}/series/${SeriesInstanceUID}/instances/${i}/frames/1`;
          cornerstone.loadImage(imageId).then((image: any) => {
            cornerstone.displayImage(dicomRef.current!, image);
          });
        });
      })
      .catch((error) => {
        console.error("Error fetching instances:", error);
      });
  }, []);

  return (
    <div>
      <div ref={dicomRef} style={{ width: 200, height: 200 }}></div>
    </div>
  );
};
